==> openshift-model-machineconfig-5.10.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ContainerRuntimeConfigSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ContainerRuntimeConfigSpecFluentImpl<A extends io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent<A>{
  public ContainerRuntimeConfigSpecFluentImpl() {
  }
  public ContainerRuntimeConfigSpecFluentImpl(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpec instance) {
    this.withContainerRuntimeConfig(instance.getContainerRuntimeConfig()); 
    this.withMachineConfigPoolSelector(instance.getMachineConfigPoolSelector()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder containerRuntimeConfig;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder machineConfigPoolSelector;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildContainerRuntimeConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration getContainerRuntimeConfig() {
    return this.containerRuntimeConfig!=null?this.containerRuntimeConfig.build():null;
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration buildContainerRuntimeConfig() {
    return this.containerRuntimeConfig!=null?this.containerRuntimeConfig.build():null;
  }
  public A withContainerRuntimeConfig(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration containerRuntimeConfig) {
    _visitables.get("containerRuntimeConfig").remove(this.containerRuntimeConfig);
    if (containerRuntimeConfig!=null){ this.containerRuntimeConfig= new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder(containerRuntimeConfig); _visitables.get("containerRuntimeConfig").add(this.containerRuntimeConfig);} return (A) this;
  }
  public java.lang.Boolean hasContainerRuntimeConfig() {
    return this.containerRuntimeConfig != null;
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> withNewContainerRuntimeConfig() {
    return new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> withNewContainerRuntimeConfigLike(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration item) {
    return new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> editContainerRuntimeConfig() {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> editOrNewContainerRuntimeConfig() {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig() != null ? getContainerRuntimeConfig(): new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder().build());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> editOrNewContainerRuntimeConfigLike(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration item) {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig() != null ? getContainerRuntimeConfig(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMachineConfigPoolSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null?this.machineConfigPoolSelector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null?this.machineConfigPoolSelector.build():null;
  }
  public A withMachineConfigPoolSelector(io.fabric8.kubernetes.api.model.LabelSelector machineConfigPoolSelector) {
    _visitables.get("machineConfigPoolSelector").remove(this.machineConfigPoolSelector);
    if (machineConfigPoolSelector!=null){ this.machineConfigPoolSelector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(machineConfigPoolSelector); _visitables.get("machineConfigPoolSelector").add(this.machineConfigPoolSelector);} return (A) this;
  }
  public java.lang.Boolean hasMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector != null;
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelector() {
    return new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> editMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerRuntimeConfigSpecFluentImpl that = (ContainerRuntimeConfigSpecFluentImpl) o;
    if (containerRuntimeConfig != null ? !containerRuntimeConfig.equals(that.containerRuntimeConfig) :that.containerRuntimeConfig != null) return false;
    if (machineConfigPoolSelector != null ? !machineConfigPoolSelector.equals(that.machineConfigPoolSelector) :that.machineConfigPoolSelector != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerRuntimeConfig,  machineConfigPoolSelector,  additionalProperties,  super.hashCode());
  }
  public class ContainerRuntimeConfigNestedImpl<N> extends io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<N>> implements io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ContainerRuntimeConfigNestedImpl(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration item) {
      this.builder = new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder(this, item);
    }
    ContainerRuntimeConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder(this);
    }
    io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigSpecFluentImpl.this.withContainerRuntimeConfig(builder.build());
    }
    public N endContainerRuntimeConfig() {
      return and();
    }
    
  }
  public class MachineConfigPoolSelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<N>> implements io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MachineConfigPoolSelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    MachineConfigPoolSelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigSpecFluentImpl.this.withMachineConfigPoolSelector(builder.build());
    }
    public N endMachineConfigPoolSelector() {
      return and();
    }
    
  }
  
}

==> openshift-model-machineconfig-5.12.3-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ContainerRuntimeConfigSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ContainerRuntimeConfigSpecFluentImpl<A extends io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent<A>{
  public ContainerRuntimeConfigSpecFluentImpl() {
  }
  public ContainerRuntimeConfigSpecFluentImpl(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpec instance) {
    this.withContainerRuntimeConfig(instance.getContainerRuntimeConfig()); 
    this.withMachineConfigPoolSelector(instance.getMachineConfigPoolSelector()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder containerRuntimeConfig;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder machineConfigPoolSelector;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildContainerRuntimeConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration getContainerRuntimeConfig() {
    return this.containerRuntimeConfig!=null?this.containerRuntimeConfig.build():null;
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration buildContainerRuntimeConfig() {
    return this.containerRuntimeConfig!=null?this.containerRuntimeConfig.build():null;
  }
  public A withContainerRuntimeConfig(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration containerRuntimeConfig) {
    _visitables.get("containerRuntimeConfig").remove(this.containerRuntimeConfig);
    if (containerRuntimeConfig!=null){ this.containerRuntimeConfig= new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder(containerRuntimeConfig); _visitables.get("containerRuntimeConfig").add(this.containerRuntimeConfig);} return (A) this;
  }
  public java.lang.Boolean hasContainerRuntimeConfig() {
    return this.containerRuntimeConfig != null;
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> withNewContainerRuntimeConfig() {
    return new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> withNewContainerRuntimeConfigLike(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration item) {
    return new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> editContainerRuntimeConfig() {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> editOrNewContainerRuntimeConfig() {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig() != null ? getContainerRuntimeConfig(): new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder().build());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> editOrNewContainerRuntimeConfigLike(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration item) {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig() != null ? getContainerRuntimeConfig(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMachineConfigPoolSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null?this.machineConfigPoolSelector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null?this.machineConfigPoolSelector.build():null;
  }
  public A withMachineConfigPoolSelector(io.fabric8.kubernetes.api.model.LabelSelector machineConfigPoolSelector) {
    _visitables.get("machineConfigPoolSelector").remove(this.machineConfigPoolSelector);
    if (machineConfigPoolSelector!=null){ this.machineConfigPoolSelector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(machineConfigPoolSelector); _visitables.get("machineConfigPoolSelector").add(this.machineConfigPoolSelector);} return (A) this;
  }
  public java.lang.Boolean hasMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector != null;
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelector() {
    return new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> editMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerRuntimeConfigSpecFluentImpl that = (ContainerRuntimeConfigSpecFluentImpl) o;
    if (containerRuntimeConfig != null ? !containerRuntimeConfig.equals(that.containerRuntimeConfig) :that.containerRuntimeConfig != null) return false;
    if (machineConfigPoolSelector != null ? !machineConfigPoolSelector.equals(that.machineConfigPoolSelector) :that.machineConfigPoolSelector != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerRuntimeConfig,  machineConfigPoolSelector,  additionalProperties,  super.hashCode());
  }
  public class ContainerRuntimeConfigNestedImpl<N> extends io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<N>> implements io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ContainerRuntimeConfigNestedImpl(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration item) {
      this.builder = new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder(this, item);
    }
    ContainerRuntimeConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder(this);
    }
    io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigSpecFluentImpl.this.withContainerRuntimeConfig(builder.build());
    }
    public N endContainerRuntimeConfig() {
      return and();
    }
    
  }
  public class MachineConfigPoolSelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<N>> implements io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MachineConfigPoolSelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    MachineConfigPoolSelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigSpecFluentImpl.this.withMachineConfigPoolSelector(builder.build());
    }
    public N endMachineConfigPoolSelector() {
      return and();
    }
    
  }
  
}
